import { Pitch } from "../../../Common/DataObjects/Pitch";
import { AbstractNotationInstruction } from "./AbstractNotationInstruction";
/**
 * A [[ClefInstruction]] is the clef placed at the beginning of the stave, which indicates the pitch of the notes.
 */
export declare class ClefInstruction extends AbstractNotationInstruction {
    constructor(clefType?: ClefEnum, octaveOffset?: number, line?: number);
    private clefType;
    private line;
    private octaveOffset;
    private clefPitch;
    private referenceCyPosition;
    static getDefaultClefFromMidiInstrument(instrument: MidiInstrument): ClefInstruction;
    static getAllPossibleClefs(): ClefInstruction[];
    static isSupportedClef(clef: ClefEnum): boolean;
    get ClefType(): ClefEnum;
    set ClefType(value: ClefEnum);
    get Line(): number;
    set Line(value: number);
    get OctaveOffset(): number;
    set OctaveOffset(value: number);
    get ClefPitch(): Pitch;
    set ClefPitch(value: Pitch);
    get ReferenceCyPosition(): number;
    set ReferenceCyPosition(value: number);
    Equals(other: ClefInstruction): boolean;
    NotEqual(clef2: ClefInstruction): boolean;
    ToString(): string;
    private calcParameters;
}
export declare enum ClefEnum {
    G = 0,
    F = 1,
    C = 2,
    percussion = 3,
    TAB = 4
}
export declare enum MidiInstrument {
    None = -1,
    Acoustic_Grand_Piano = 0,
    Bright_Acoustic_Piano = 1,
    Electric_Grand_Piano = 2,
    Honky_tonk_Piano = 3,
    Electric_Piano_1 = 4,
    Electric_Piano_2 = 5,
    Harpsichord = 6,
    Clavinet = 7,
    Celesta = 8,
    Glockenspiel = 9,
    Music_Box = 10,
    Vibraphone = 11,
    Marimba = 12,
    Xylophone = 13,
    Tubular_Bells = 14,
    Dulcimer = 15,
    Drawbar_Organ = 16,
    Percussive_Organ = 17,
    Rock_Organ = 18,
    Church_Organ = 19,
    Reed_Organ = 20,
    Accordion = 21,
    Harmonica = 22,
    Tango_Accordion = 23,
    Acoustic_Guitar_nylon = 24,
    Acoustic_Guitar_steel = 25,
    Electric_Guitar_jazz = 26,
    Electric_Guitar_clean = 27,
    Electric_Guitar_muted = 28,
    Overdriven_Guitar = 29,
    Distortion_Guitar = 30,
    Guitar_harmonics = 31,
    Acoustic_Bass = 32,
    Electric_Bass_finger = 33,
    Electric_Bass_pick = 34,
    Fretless_Bass = 35,
    Slap_Bass_1 = 36,
    Slap_Bass_2 = 37,
    Synth_Bass_1 = 38,
    Synth_Bass_2 = 39,
    Violin = 40,
    Viola = 41,
    Cello = 42,
    Contrabass = 43,
    Tremolo_Strings = 44,
    Pizzicato_Strings = 45,
    Orchestral_Harp = 46,
    Timpani = 47,
    String_Ensemble_1 = 48,
    String_Ensemble_2 = 49,
    Synth_Strings_1 = 50,
    Synth_Strings_2 = 51,
    Choir_Aahs = 52,
    Voice_Oohs = 53,
    Synth_Voice = 54,
    Orchestra_Hit = 55,
    Trumpet = 56,
    Trombone = 57,
    Tuba = 58,
    Muted_Trumpet = 59,
    French_Horn = 60,
    Brass_Section = 61,
    Synth_Brass_1 = 62,
    Synth_Brass_2 = 63,
    Soprano_Sax = 64,
    Alto_Sax = 65,
    Tenor_Sax = 66,
    Baritone_Sax = 67,
    Oboe = 68,
    English_Horn = 69,
    Bassoon = 70,
    Clarinet = 71,
    Piccolo = 72,
    Flute = 73,
    Recorder = 74,
    Pan_Flute = 75,
    Blown_Bottle = 76,
    Shakuhachi = 77,
    Whistle = 78,
    Ocarina = 79,
    Lead_1_square = 80,
    Lead_2_sawtooth = 81,
    Lead_3_calliope = 82,
    Lead_4_chiff = 83,
    Lead_5_charang = 84,
    Lead_6_voice = 85,
    Lead_7_fifths = 86,
    Lead_8_bass_lead = 87,
    Pad_1_new_age = 88,
    Pad_2_warm = 89,
    Pad_3_polysynth = 90,
    Pad_4_choir = 91,
    Pad_5_bowed = 92,
    Pad_6_metallic = 93,
    Pad_7_halo = 94,
    Pad_8_sweep = 95,
    FX_1_rain = 96,
    FX_2_soundtrack = 97,
    FX_3_crystal = 98,
    FX_4_atmosphere = 99,
    FX_5_brightness = 100,
    FX_6_goblins = 101,
    FX_7_echoes = 102,
    FX_8_scifi = 103,
    Sitar = 104,
    Banjo = 105,
    Shamisen = 106,
    Koto = 107,
    Kalimba = 108,
    Bag_pipe = 109,
    Fiddle = 110,
    Shanai = 111,
    Tinkle_Bell = 112,
    Agogo = 113,
    Steel_Drums = 114,
    Woodblock = 115,
    Taiko_Drum = 116,
    Melodic_Tom = 117,
    Synth_Drum = 118,
    Reverse_Cymbal = 119,
    Guitar_Fret_Noise = 120,
    Breath_Noise = 121,
    Seashore = 122,
    Bird_Tweet = 123,
    Telephone_Ring = 124,
    Helicopter = 125,
    Applause = 126,
    Gunshot = 127,
    Percussion = 128
}
